@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 import os
 import logging
+from appdirs import AppDirs
 from random import randint, choice
 
-basedir = os.path.abspath(os.path.dirname(__file__))
-logdir  = f"{basedir}/gamelogs/"
+
+logdir = AppDirs("craps", "gamelogs")
+
 
 def create_logger(game_id, level=logging.INFO):
     # Create a custom logger
@@ -36,8 +38,7 @@ def purge_logs():
     if not os.path.exists(logdir):
         os.mkdir(logdir)
     for f in [f for f in os.listdir(logdir)]:
-        if not f == '.keepalive':
-            os.remove(f"{logdir}{f}")
+        os.remove(f"{logdir}{f}")
 
 class TestRoll():
     def __init__(self, override=(None, None)):
